# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [0.1.2](https://github.com/mcw-meier-lab/pyFSViz/releases/tag/0.1.2) - 2025-10-28

<small>[Compare with 0.1.1](https://github.com/mcw-meier-lab/pyFSViz/compare/0.1.1...0.1.2)</small>

## [0.1.1](https://github.com/mcw-meier-lab/pyFSViz/releases/tag/0.1.1) - 2025-10-28

<small>[Compare with 0.1.0](https://github.com/mcw-meier-lab/pyFSViz/compare/0.1.0...0.1.1)</small>

## [0.1.0](https://github.com/mcw-meier-lab/pyFSViz/releases/tag/0.1.0) - 2025-10-27

<small>[Compare with first commit](https://github.com/mcw-meier-lab/pyFSViz/compare/2acb6743e94b41c05bfeed9c5a1c94f2b566483a...0.1.0)</small>

### Build

- drop python 3.9 ([4b21f95](https://github.com/mcw-meier-lab/pyFSViz/commit/4b21f955150bfaefe3c1aa6e68490636f05ee907) by Lezlie Espana).

### Features

- inital commit ([2acb674](https://github.com/mcw-meier-lab/pyFSViz/commit/2acb6743e94b41c05bfeed9c5a1c94f2b566483a) by Lezlie Espana).

### Code Refactoring

- add batch html report workflow ([10d6423](https://github.com/mcw-meier-lab/pyFSViz/commit/10d64237dad1f8b46496b25a0f2c63dc254134b6) by Lezlie Espana).
- add initial html reports ([d118911](https://github.com/mcw-meier-lab/pyFSViz/commit/d118911420a0e886e2a0c6fa1aa1fd128057d0af) by Lezlie Espana).
- add initial figure generation ([0ff4807](https://github.com/mcw-meier-lab/pyFSViz/commit/0ff48073e87e9f17b1e9ba6abf42b30759cf06c0) by Lezlie Espana).
- style, typing, testing ([fb176fa](https://github.com/mcw-meier-lab/pyFSViz/commit/fb176faf46bdc7351ea030fd617dfef36fc6b3dd) by Lezlie Espana).
- add initial fs class ([53864e8](https://github.com/mcw-meier-lab/pyFSViz/commit/53864e8a5168e8ab5ec8016998a81109d444bc6e) by Lezlie Espana).
